@@ -18,7 +18,7 @@ class DingTalk():
         self.webhook = webhook
         self.secret = secret
 
-    def send_message(self, receiver, content):
+    def send_message(self, receivers, content):
 
         data = {
             "msgtype": "text",
@@ -26,9 +26,7 @@ class DingTalk():
                 "content": str(content)
             },
             "at": {
-                "atMobiles": [
-                    receiver
-                ],
+                "atMobiles":receivers,
                 "isAtAll": False
             }
         }
@@ -50,3 +48,10 @@ class DingTalk():
                 return Response(code=500, success=False, data=json.loads(data))
         except Exception as e:
             return Response(code=500, success=False, data=json.loads(data))
+
+    def test(self,receiver):
+
+        test = {
+            "re":[receiver]
+        }
+        print(test['re'])
\ No newline at end of file
